@@ -285,9 +285,12 @@ real_append_query_headers (GDataService *self, GDataAuthorizationDomain *domain,
 	if (self->priv->authorizer != NULL) {
 		gdata_authorizer_process_request (self->priv->authorizer, domain, message);
 
-		/* Store the authorisation domain on the message so that we can access it again after refreshing authorisation if necessary.
-		 * See _gdata_service_send_message(). */
-		g_object_set_data_full (G_OBJECT (message), "gdata-authorization-domain", g_object_ref (domain), (GDestroyNotify) g_object_unref);
+		if (domain != NULL) {
+			/* Store the authorisation domain on the message so that we can access it again after refreshing authorisation if necessary.
+			 * See _gdata_service_send_message(). */
+			g_object_set_data_full (G_OBJECT (message), "gdata-authorization-domain", g_object_ref (domain),
+			                        (GDestroyNotify) g_object_unref);
+		}
 	}
 
 	/* Set the GData-Version header to tell it we want to use the v2 API */
@@ -627,16 +630,22 @@ _gdata_service_actually_send_message (SoupSession *session, SoupMessage *message
 	}
 
 	/* Set the cancellation error if applicable. We can't assume that our GCancellable has been cancelled just because the message has;
-	 * libsoup may internally cancel messages if, for example, the proxy URI of the SoupSession is changed. */
+	 * libsoup may internally cancel messages if, for example, the proxy URI of the SoupSession is changed.
+	 * libsoup also sometimes seems to return a SOUP_STATUS_IO_ERROR when we cancel a message, even though we've specified SOUP_STATUS_CANCELLED
+	 * at cancellation time. Ho Hum. */
 	g_assert (message->status_code != SOUP_STATUS_NONE);
 
-	if (message->status_code == SOUP_STATUS_CANCELLED) {
+	if (message->status_code == SOUP_STATUS_CANCELLED ||
+	    (message->status_code == SOUP_STATUS_IO_ERROR && cancellable != NULL && g_cancellable_is_cancelled (cancellable) == TRUE)) {
 		/* We hackily create and cancel a new GCancellable so that we can set the error using it and therefore save ourselves a translatable
 		 * string and the associated maintenance. */
 		GCancellable *error_cancellable = g_cancellable_new ();
 		g_cancellable_cancel (error_cancellable);
 		g_assert (g_cancellable_set_error_if_cancelled (error_cancellable, error) == TRUE);
 		g_object_unref (error_cancellable);
+
+		/* As per the above comment, force the status to be SOUP_STATUS_CANCELLED. */
+		soup_message_set_status (message, SOUP_STATUS_CANCELLED);
 	}
 
 	/* Free things */
@@ -802,6 +811,7 @@ gdata_service_query_async (GDataService *self, GDataAuthorizationDomain *domain,
 	data->feed_uri = g_strdup (feed_uri);
 	data->query = (query != NULL) ? g_object_ref (query) : NULL;
 	data->entry_type = entry_type;
+	data->feed = NULL;
 	data->progress_callback = progress_callback;
 	data->progress_user_data = progress_user_data;
 	data->destroy_progress_user_data = destroy_progress_user_data;
@@ -1682,6 +1692,7 @@ gdata_service_delete_entry (GDataService *self, GDataAuthorizationDomain *domain
 	GDataLink *_link;
 	SoupMessage *message;
 	guint status;
+	gchar *fixed_uri;
 
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), FALSE);
 	g_return_val_if_fail (domain == NULL || GDATA_IS_AUTHORIZATION_DOMAIN (domain), FALSE);
@@ -1689,10 +1700,13 @@ gdata_service_delete_entry (GDataService *self, GDataAuthorizationDomain *domain
 	g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	/* Get the edit URI */
+	/* Get the edit URI. We have to fix it to always use HTTPS as YouTube videos appear to incorrectly return a HTTP URI as their edit URI. */
 	_link = gdata_entry_look_up_link (entry, GDATA_LINK_EDIT);
 	g_assert (_link != NULL);
-	message = _gdata_service_build_message (self, domain, SOUP_METHOD_DELETE, gdata_link_get_uri (_link), gdata_entry_get_etag (entry), TRUE);
+
+	fixed_uri = _gdata_service_fix_uri_scheme (gdata_link_get_uri (_link));
+	message = _gdata_service_build_message (self, domain, SOUP_METHOD_DELETE, fixed_uri, gdata_entry_get_etag (entry), TRUE);
+	g_free (fixed_uri);
 
 	/* Send the message */
 	status = _gdata_service_send_message (self, message, cancellable, error);
