@@ -37,6 +37,58 @@
  * gdata_contacts_group_get_extended_property(), are provided as a method of storing client-specific data which shouldn't be seen or be editable
  * by the user, such as IDs and cache times.
  *
+ * <example>
+ * 	<title>Adding a New Group</title>
+ * 	<programlisting>
+ *	GDataContactsService *service;
+ *	GDataContactsGroup *group, *updated_group;
+ *	GDataContactsContact *contact, *updated_contact;
+ *	GError *error = NULL;
+ *
+ *	/<!-- -->* Create a service and return a contact to add to the new group. *<!-- -->/
+ *	service = create_contacts_service ();
+ *	contact = query_user_for_contact (service);
+ *
+ *	/<!-- -->* Create the new group *<!-- -->/
+ *	group = gdata_contacts_group_new (NULL);
+ *	gdata_entry_set_title (GDATA_ENTRY (group), "Group Name");
+ *
+ *	/<!-- -->* Insert the group on the server *<!-- -->/
+ *	updated_group = gdata_contacts_service_insert_group (service, group, NULL, &error);
+ *
+ *	g_object_unref (group);
+ *
+ *	if (error != NULL) {
+ *		g_error ("Error adding a group: %s", error->message);
+ *		g_error_free (error);
+ *		g_object_unref (contact);
+ *		g_object_unref (service);
+ *		return;
+ *	}
+ *
+ *	/<!-- -->* Add the contact to the new group. *<!-- -->/
+ *	gdata_contacts_contact_add_group (contact, gdata_entry_get_id (GDATA_ENTRY (updated_group)));
+ *
+ *	g_object_unref (updated_group);
+ *
+ *	/<!-- -->* Update the contact on the server *<!-- -->/
+ *	updated_contact = GDATA_CONTACTS_CONTACT (gdata_service_update_entry (GDATA_SERVICE (service), GDATA_ENTRY (contact), NULL, &error));
+ *
+ *	g_object_unref (contact);
+ *	g_object_unref (service);
+ *
+ *	if (error != NULL) {
+ *		g_error ("Error updating contact: %s", error->message);
+ *		g_error_free (error);
+ *		return;
+ *	}
+ *
+ *	/<!-- -->* Do something with the updated contact, such as update them in the UI, or store their ID for future use. *<!-- -->/
+ *
+ *	g_object_unref (updated_contact);
+ * 	</programlisting>
+ * </example>
+ *
  * Since: 0.7.0
  **/
 
@@ -354,8 +406,9 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 static void
 get_extended_property_xml_cb (const gchar *name, const gchar *value, GString *xml_string)
 {
-	/* TODO */
-	g_string_append_printf (xml_string, "<gd:extendedProperty name='%s'>%s</gd:extendedProperty>", name, value);
+	/* Note that the value *isn't* escaped (see http://code.google.com/apis/gdata/docs/2.0/elements.html#gdExtendedProperty) */
+	gdata_parser_string_append_escaped (xml_string, "<gd:extendedProperty name='", name, "'>");
+	g_string_append_printf (xml_string, "%s</gd:extendedProperty>", value);
 }
 
 static void
